# MLPug
A machine learning library agnostic framework for model training

## Installing MLPug
Please ensure that you are using Python3.7+.

Install as follows:
```
pip install mlpug
```

## Usage with PyTorch
When you want to use MLPug with PyTorch, you will need to install it:
```
pip install torch torchvision
``` 
